@@ -7,6 +7,7 @@ use Dancer::Plugin::Auth::Extensible;
 
 use List::Util 'first';
 use List::MoreUtils ();
+use App::Netdisco::Util::Port 'to_speed';
 use App::Netdisco::Util::Permission 'acl_matches';
 use App::Netdisco::Web::Plugin;
 
@@ -80,36 +81,6 @@ ajax '/ajax/data/device/netmappositions' => require_login sub {
     }
 };
 
-# copied from SNMP::Info to avoid introducing dependency to web frontend
-sub munge_highspeed {
-    my $speed = shift;
-    my $fmt   = "%d Mbps";
-
-    if ( $speed > 9999999 ) {
-        $fmt = "%d Tbps";
-        $speed /= 1000000;
-    }
-    elsif ( $speed > 999999 ) {
-        $fmt = "%.1f Tbps";
-        $speed /= 1000000.0;
-    }
-    elsif ( $speed > 9999 ) {
-        $fmt = "%d Gbps";
-        $speed /= 1000;
-    }
-    elsif ( $speed > 999 ) {
-        $fmt = "%.1f Gbps";
-        $speed /= 1000.0;
-    }
-    return sprintf( $fmt, $speed );
-}
-
-sub to_speed {
-  my $speed = shift or return '';
-  ($speed = munge_highspeed($speed / 1_000_000)) =~ s/(?:\.0 |bps$)//g;
-  return $speed;
-}
-
 sub make_node_infostring {
   my $node = shift or return '';
   my $fmt = ('<b>%s</b> is %s <b>%s %s</b><br>running <b>%s %s</b><br>Serial: <b>%s</b><br>'
